List all comments on a workflow, sorted by creation date.
See also
Other api-comments:
api_comment_recipe(),
api_comment_workflow(),
api_delete_comment(),
api_get_recipe_comments()
List all comments on a workflow, sorted by creation date.
Other api-comments:
api_comment_recipe(),
api_comment_workflow(),
api_delete_comment(),
api_get_recipe_comments()