Give a star rating (1-5) to a recipe. Requires authentication. Each user can have one rating per recipe (upserts on subsequent calls).
See also
Other api-stars:
api_get_recipe_stars(),
api_get_workflow_stars(),
api_star_workflow()
Give a star rating (1-5) to a recipe. Requires authentication. Each user can have one rating per recipe (upserts on subsequent calls).
Other api-stars:
api_get_recipe_stars(),
api_get_workflow_stars(),
api_star_workflow()