Skip to contents

Retrieves the currently configured engine for loading surveys from system options or environment variables.

Usage

get_engine()

Value

Character vector with the name of the configured engine.

Examples

get_engine()
#> [1] "data.table"