This class represents a collection of surveys grouped by specific periods (e.g., monthly, quarterly, annual). It provides methods to access and manipulate the grouped surveys.
See also
Other panel-surveys:
RotativePanelSurvey,
extract_surveys(),
get_follow_up(),
get_implantation()
Methods
Examples
s1 <- Survey$new(
data = data.table::data.table(id = 1:3, w = 1),
edition = "2023", type = "test", psu = NULL,
engine = "data.table", weight = add_weight(annual = "w")
)
s2 <- Survey$new(
data = data.table::data.table(id = 4:6, w = 1),
edition = "2023", type = "test", psu = NULL,
engine = "data.table", weight = add_weight(annual = "w")
)
pool <- PoolSurvey$new(list(annual = list("group1" = list(s1, s2))))